@@ -13,7 +13,7 @@ import (
 
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 	"k8s.io/kubectl/pkg/cmd/diff"
-	"k8s.io/kubectl/pkg/cmd/kustomize"
+
 	"k8s.io/kubectl/pkg/cmd/plugin"
 	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
 	ktemplates "k8s.io/kubectl/pkg/util/templates"
@@ -21,8 +21,6 @@ import (
 
 	"github.com/openshift/oc/pkg/cli/admin"
 	"github.com/openshift/oc/pkg/cli/admin/buildchain"
-	"github.com/openshift/oc/pkg/cli/admin/groups/sync"
-	"github.com/openshift/oc/pkg/cli/buildlogs"
 	"github.com/openshift/oc/pkg/cli/cancelbuild"
 	"github.com/openshift/oc/pkg/cli/debug"
 	"github.com/openshift/oc/pkg/cli/deployer"
@@ -76,22 +74,22 @@ var (
 	cliExplain = heredoc.Doc(`
     To familiarize yourself with OpenShift, login to your cluster and try creating a sample application:
 
-        %[1]s login mycluster.mycompany.com
-        %[1]s new-project my-example
-        %[1]s new-app django-psql-example
-        %[1]s logs -f bc/django-psql-example
+        oc login mycluster.mycompany.com
+        oc new-project my-example
+        oc new-app django-psql-example
+        oc logs -f bc/django-psql-example
 
     To see what has been created, run:
 
-        %[1]s status
+        oc status
 
     and get a command shell inside one of the created containers with:
 
-        %[1]s rsh dc/postgresql
+        oc rsh dc/postgresql
 
     To see the list of available toolchains for building applications, run:
 
-        %[1]s new-app -L
+        oc new-app -L
 
     Since OpenShift runs on top of Kubernetes, your favorite kubectl commands are also present in oc,
     allowing you to quickly switch between development and debugging. You can also run kubectl directly
@@ -99,11 +97,11 @@ var (
 
     For more on OpenShift, see the documentation at https://docs.openshift.com.
 
-    To see the full list of commands supported, run '%[1]s --help'.`)
+    To see the full list of commands supported, run 'oc --help'.`)
 )
 
-func NewDefaultOcCommand(name, fullName string, in io.Reader, out, errout io.Writer) *cobra.Command {
-	cmd := NewOcCommand(name, fullName, in, out, errout)
+func NewDefaultOcCommand(in io.Reader, out, errout io.Writer) *cobra.Command {
+	cmd := NewOcCommand(in, out, errout)
 
 	if len(os.Args) <= 1 {
 		return cmd
@@ -124,17 +122,17 @@ func NewDefaultOcCommand(name, fullName string, in io.Reader, out, errout io.Wri
 	return cmd
 }
 
-func NewOcCommand(name, fullName string, in io.Reader, out, errout io.Writer) *cobra.Command {
+func NewOcCommand(in io.Reader, out, errout io.Writer) *cobra.Command {
 	// Main command
 	cmds := &cobra.Command{
-		Use:   name,
+		Use:   "oc",
 		Short: "Command line tools for managing applications",
 		Long:  cliLong,
 		Run: func(c *cobra.Command, args []string) {
 			explainOut := term.NewResponsiveWriter(out)
 			c.SetOutput(explainOut)
 			kcmdutil.RequireNoArguments(c, args)
-			fmt.Fprintf(explainOut, "%s\n\n%s\n", cliLong, fmt.Sprintf(cliExplain, fullName))
+			fmt.Fprintf(explainOut, "%s\n\n%s\n", cliLong, cliExplain)
 		},
 		BashCompletionFunction: bashCompletionFunc,
 	}
@@ -148,127 +146,115 @@ func NewOcCommand(name, fullName string, in io.Reader, out, errout io.Writer) *c
 
 	ioStreams := genericclioptions.IOStreams{In: in, Out: out, ErrOut: errout}
 
-	loginCmd := login.NewCmdLogin(fullName, f, ioStreams)
-	secretcmds := secrets.NewCmdSecrets(secrets.SecretsRecommendedName, fullName+" "+secrets.SecretsRecommendedName, f, ioStreams)
+	loginCmd := login.NewCmdLogin(f, ioStreams)
+	secretcmds := secrets.NewCmdSecrets(f, ioStreams)
 
 	groups := ktemplates.CommandGroups{
 		{
 			Message: "Basic Commands:",
 			Commands: []*cobra.Command{
 				loginCmd,
-				requestproject.NewCmdRequestProject(fullName, f, ioStreams),
-				newapp.NewCmdNewApplication(newapp.NewAppRecommendedCommandName, fullName, f, ioStreams),
-				status.NewCmdStatus(status.StatusRecommendedName, fullName, fullName+" "+status.StatusRecommendedName, f, ioStreams),
-				project.NewCmdProject(fullName, f, ioStreams),
-				projects.NewCmdProjects(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdExplain(fullName, f, ioStreams),
+				requestproject.NewCmdRequestProject(f, ioStreams),
+				newapp.NewCmdNewApplication(f, ioStreams),
+				status.NewCmdStatus(f, ioStreams),
+				project.NewCmdProject(f, ioStreams),
+				projects.NewCmdProjects(f, ioStreams),
+				kubectlwrappers.NewCmdExplain(f, ioStreams),
 			},
 		},
 		{
 			Message: "Build and Deploy Commands:",
 			Commands: []*cobra.Command{
-				rollout.NewCmdRollout(fullName, f, ioStreams),
-				rollback.NewCmdRollback(fullName, f, ioStreams),
-				newbuild.NewCmdNewBuild(newbuild.NewBuildRecommendedCommandName, fullName, f, ioStreams),
-				startbuild.NewCmdStartBuild(fullName, f, ioStreams),
-				cancelbuild.NewCmdCancelBuild(cancelbuild.CancelBuildRecommendedCommandName, fullName, f, ioStreams),
-				importimage.NewCmdImportImage(fullName, f, ioStreams),
-				tag.NewCmdTag(fullName, f, ioStreams),
+				rollout.NewCmdRollout(f, ioStreams),
+				rollback.NewCmdRollback(f, ioStreams),
+				newbuild.NewCmdNewBuild(f, ioStreams),
+				startbuild.NewCmdStartBuild(f, ioStreams),
+				cancelbuild.NewCmdCancelBuild(f, ioStreams),
+				importimage.NewCmdImportImage(f, ioStreams),
+				tag.NewCmdTag(f, ioStreams),
 			},
 		},
 		{
 			Message: "Application Management Commands:",
 			Commands: []*cobra.Command{
-				kubectlwrappers.NewCmdCreate(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdApply(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdGet(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdDescribe(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdEdit(fullName, f, ioStreams),
-				set.NewCmdSet(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdLabel(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdAnnotate(fullName, f, ioStreams),
-				expose.NewCmdExpose(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdDelete(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdScale(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdAutoscale(fullName, f, ioStreams),
+				kubectlwrappers.NewCmdCreate(f, ioStreams),
+				kubectlwrappers.NewCmdApply(f, ioStreams),
+				kubectlwrappers.NewCmdGet(f, ioStreams),
+				kubectlwrappers.NewCmdDescribe(f, ioStreams),
+				kubectlwrappers.NewCmdEdit(f, ioStreams),
+				set.NewCmdSet(f, ioStreams),
+				kubectlwrappers.NewCmdLabel(f, ioStreams),
+				kubectlwrappers.NewCmdAnnotate(f, ioStreams),
+				expose.NewCmdExpose(f, ioStreams),
+				kubectlwrappers.NewCmdDelete(f, ioStreams),
+				kubectlwrappers.NewCmdScale(f, ioStreams),
+				kubectlwrappers.NewCmdAutoscale(f, ioStreams),
 				secretcmds,
-				serviceaccounts.NewCmdServiceAccounts(serviceaccounts.ServiceAccountsRecommendedName, fullName+" "+serviceaccounts.ServiceAccountsRecommendedName, f, ioStreams),
+				serviceaccounts.NewCmdServiceAccounts(f, ioStreams),
 			},
 		},
 		{
 			Message: "Troubleshooting and Debugging Commands:",
 			Commands: []*cobra.Command{
-				logs.NewCmdLogs(logs.LogsRecommendedCommandName, fullName, f, ioStreams),
-				rsh.NewCmdRsh(rsh.RshRecommendedName, fullName, f, ioStreams),
-				rsync.NewCmdRsync(rsync.RsyncRecommendedName, fullName, f, ioStreams),
-				kubectlwrappers.NewCmdPortForward(fullName, f, ioStreams),
-				debug.NewCmdDebug(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdExec(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdProxy(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdAttach(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdRun(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdCp(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdWait(fullName, f, ioStreams),
+				logs.NewCmdLogs(f, ioStreams),
+				rsh.NewCmdRsh(f, ioStreams),
+				rsync.NewCmdRsync(f, ioStreams),
+				kubectlwrappers.NewCmdPortForward(f, ioStreams),
+				debug.NewCmdDebug(f, ioStreams),
+				kubectlwrappers.NewCmdExec(f, ioStreams),
+				kubectlwrappers.NewCmdProxy(f, ioStreams),
+				kubectlwrappers.NewCmdAttach(f, ioStreams),
+				kubectlwrappers.NewCmdRun(f, ioStreams),
+				kubectlwrappers.NewCmdCp(f, ioStreams),
+				kubectlwrappers.NewCmdWait(f, ioStreams),
 			},
 		},
 		{
 			Message: "Advanced Commands:",
 			Commands: []*cobra.Command{
-				admin.NewCommandAdmin("adm", fullName+" "+"adm", f, ioStreams),
-				kubectlwrappers.NewCmdReplace(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdPatch(fullName, f, ioStreams),
-				process.NewCmdProcess(fullName, f, ioStreams),
-				extract.NewCmdExtract(fullName, f, ioStreams),
-				observe.NewCmdObserve(fullName, f, ioStreams),
-				policy.NewCmdPolicy(policy.PolicyRecommendedName, fullName+" "+policy.PolicyRecommendedName, f, ioStreams),
-				kubectlwrappers.NewCmdAuth(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdConvert(fullName, f, ioStreams),
-				image.NewCmdImage(fullName, f, ioStreams),
-				registry.NewCmd(fullName, f, ioStreams),
-				idle.NewCmdIdle(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdApiVersions(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdApiResources(fullName, f, ioStreams),
-				kubectlwrappers.NewCmdClusterInfo(fullName, f, ioStreams),
+				admin.NewCommandAdmin(f, ioStreams),
+				kubectlwrappers.NewCmdReplace(f, ioStreams),
+				kubectlwrappers.NewCmdPatch(f, ioStreams),
+				process.NewCmdProcess(f, ioStreams),
+				extract.NewCmdExtract(f, ioStreams),
+				observe.NewCmdObserve(f, ioStreams),
+				policy.NewCmdPolicy(f, ioStreams),
+				kubectlwrappers.NewCmdAuth(f, ioStreams),
+				kubectlwrappers.NewCmdConvert(f, ioStreams),
+				image.NewCmdImage(f, ioStreams),
+				registry.NewCmd(f, ioStreams),
+				idle.NewCmdIdle(f, ioStreams),
+				kubectlwrappers.NewCmdApiVersions(f, ioStreams),
+				kubectlwrappers.NewCmdApiResources(f, ioStreams),
+				kubectlwrappers.NewCmdClusterInfo(f, ioStreams),
 				diff.NewCmdDiff(f, ioStreams),
-				kustomize.NewCmdKustomize(ioStreams),
+				kubectlwrappers.NewCmdKustomize(ioStreams),
 			},
 		},
 		{
 			Message: "Settings Commands:",
 			Commands: []*cobra.Command{
-				logout.NewCmdLogout("logout", fullName+" logout", fullName+" login", f, ioStreams),
-				kubectlwrappers.NewCmdConfig(fullName, "config", f, ioStreams),
-				whoami.NewCmdWhoAmI(whoami.WhoAmIRecommendedCommandName, fullName+" "+whoami.WhoAmIRecommendedCommandName, f, ioStreams),
-				kubectlwrappers.NewCmdCompletion(fullName, ioStreams),
+				logout.NewCmdLogout(f, ioStreams),
+				kubectlwrappers.NewCmdConfig(f, ioStreams),
+				whoami.NewCmdWhoAmI(f, ioStreams),
+				kubectlwrappers.NewCmdCompletion(ioStreams),
 			},
 		},
 	}
 	groups.Add(cmds)
 
-	ocEditFullName := fullName + " edit"
-	ocSecretsFullName := fullName + " " + secrets.SecretsRecommendedName
-	ocSecretsNewFullName := ocSecretsFullName + " " + secrets.NewSecretRecommendedCommandName
-
 	filters := []string{
 		"options",
 		"deploy",
-		// These commands are deprecated and should not appear in help
-		moved(fullName, "logs", cmds, buildlogs.NewCmdBuildLogs(fullName, f, ioStreams)),
-		moved(fullName, "secrets link", secretcmds, secrets.NewCmdLinkSecret("add", fullName, f, ioStreams)),
-		moved(fullName, "create secret", secretcmds, secrets.NewCmdCreateSecret(secrets.NewSecretRecommendedCommandName, fullName, f, ioStreams)),
-		moved(fullName, "create secret", secretcmds, secrets.NewCmdCreateDockerConfigSecret(secrets.CreateDockerConfigSecretRecommendedName, fullName, f, ioStreams, ocSecretsNewFullName, ocEditFullName)),
-		moved(fullName, "create secret", secretcmds, secrets.NewCmdCreateBasicAuthSecret(secrets.CreateBasicAuthSecretRecommendedCommandName, fullName, f, ioStreams, ocSecretsNewFullName, ocEditFullName)),
-		moved(fullName, "create secret", secretcmds, secrets.NewCmdCreateSSHAuthSecret(secrets.CreateSSHAuthSecretRecommendedCommandName, fullName, f, ioStreams, ocSecretsNewFullName, ocEditFullName)),
 	}
-
 	changeSharedFlagDefaults(cmds)
 	cmdutil.ActsAsRootCommand(cmds, filters, groups...).
 		ExposeFlags(loginCmd, "certificate-authority", "insecure-skip-tls-verify", "token")
 
-	cmds.AddCommand(newExperimentalCommand("ex", name+" ex", f, ioStreams))
+	cmds.AddCommand(newExperimentalCommand(f, ioStreams))
 
-	cmds.AddCommand(kubectlwrappers.NewCmdPlugin(fullName, f, ioStreams))
-	cmds.AddCommand(version.NewCmdVersion(fullName, f, ioStreams))
+	cmds.AddCommand(kubectlwrappers.NewCmdPlugin(f, ioStreams))
+	cmds.AddCommand(version.NewCmdVersion(f, ioStreams))
 	cmds.AddCommand(options.NewCmdOptions(ioStreams))
 
 	if cmds.Flag("namespace") != nil {
@@ -318,9 +304,9 @@ func changeSharedFlagDefaults(rootCmd *cobra.Command) {
 	}
 }
 
-func newExperimentalCommand(name, fullName string, f kcmdutil.Factory, ioStreams genericclioptions.IOStreams) *cobra.Command {
+func newExperimentalCommand(f kcmdutil.Factory, ioStreams genericclioptions.IOStreams) *cobra.Command {
 	experimental := &cobra.Command{
-		Use:   name,
+		Use:   "ex",
 		Short: "Experimental commands under active development",
 		Long:  "The commands grouped here are under development and may change without notice.",
 		Run: func(c *cobra.Command, args []string) {
@@ -330,13 +316,10 @@ func newExperimentalCommand(name, fullName string, f kcmdutil.Factory, ioStreams
 		BashCompletionFunction: admin.BashCompletionFunc,
 	}
 
-	experimental.AddCommand(dockergc.NewCmdDockerGCConfig(f, fullName, "dockergc", ioStreams))
-	experimental.AddCommand(buildchain.NewCmdBuildChain(name, fullName+" "+buildchain.BuildChainRecommendedCommandName, f, ioStreams))
+	experimental.AddCommand(dockergc.NewCmdDockerGCConfig(f, ioStreams))
+	experimental.AddCommand(buildchain.NewCmdBuildChain(f, ioStreams))
 	experimental.AddCommand(options.NewCmdOptions(ioStreams))
 
-	// these groups also live under `oc adm groups {sync,prune}` and are here only for backwards compatibility
-	experimental.AddCommand(sync.NewCmdSync("sync-groups", fullName+" "+"sync-groups", f, ioStreams))
-	experimental.AddCommand(sync.NewCmdPrune("prune-groups", fullName+" "+"prune-groups", f, ioStreams))
 	return experimental
 }
 
@@ -362,7 +345,7 @@ func CommandFor(basename string) *cobra.Command {
 		cmd = recycle.NewCommandRecycle(basename, out)
 	default:
 		shimKubectlForOc()
-		cmd = NewDefaultOcCommand("oc", "oc", in, out, errout)
+		cmd = NewDefaultOcCommand(in, out, errout)
 
 		// treat oc as a kubectl plugin
 		if strings.HasPrefix(basename, "kubectl-") {
