@@ -1,8 +1,6 @@
 package registry
 
 import (
-	"fmt"
-
 	"github.com/spf13/cobra"
 
 	"k8s.io/cli-runtime/pkg/genericclioptions"
@@ -22,7 +20,7 @@ var (
 )
 
 // NewCmd exposes commands for working with the registry.
-func NewCmd(fullName string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
+func NewCmd(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
 	image := &cobra.Command{
 		Use:   "registry COMMAND",
 		Short: "Commands for working with the registry",
@@ -30,14 +28,12 @@ func NewCmd(fullName string, f kcmdutil.Factory, streams genericclioptions.IOStr
 		Run:   kcmdutil.DefaultSubCommandRun(streams.ErrOut),
 	}
 
-	name := fmt.Sprintf("%s registry", fullName)
-
 	groups := ktemplates.CommandGroups{
 		{
 			Message: "Advanced commands:",
 			Commands: []*cobra.Command{
-				info.NewRegistryInfoCmd(name, f, streams),
-				login.NewRegistryLoginCmd(name, f, streams),
+				info.NewRegistryInfoCmd(f, streams),
+				login.NewRegistryLoginCmd(f, streams),
 			},
 		},
 	}
